<div align="center">

<img src="https://github.com/xability/maidr/blob/main/logo/logo.svg" width="350px" alt="A stylized MAIDR logo, with curved characters for M A, a hand pointing for an I, the D character, and R represented in braille."/>

<hr style="color:transparent" />
<br />
</div>

# py-maidr

Python binder for maidr library

## Install and Upgrade

``` sh
# install the latest release from PyPI
pip install -U maidr

# or install the development version from GitHub
pip install -U git+https://github.com/xability/py_maidr.git
```
